@@ -9,6 +9,7 @@ Created on Sun May 26 15:06:17 2013
 """
 from math import floor
 import numpy as np
+from bisect import bisect_left
 from scipy.linalg import qr
 from scipy.sparse import lil_matrix, hstack
 from sympy import S, Number
@@ -283,7 +284,7 @@ class SdpRelaxation(object):
 
     def get_relaxation(self, obj, inequalities, equalities,
                        monomial_substitutions, order,
-                       removeequalities=True):
+                       removeequalities=False):
         """Get the SDP relaxation of a noncommutative polynomial optimization
         problem.
 
@@ -392,10 +393,7 @@ class SdpRelaxation(object):
         f.close()
 
     def __convert_row_to_SDPA_index(self, row_offsets, row):
-        block_index = 0
-        while (row_offsets[block_index] <= row):
-            block_index += 1
-        block_index -= 1
+        block_index = bisect_left(row_offsets[1:], row + 1)
         width = self.block_struct[block_index]
         row = row - row_offsets[block_index]
         i, j = divmod(row, width)
@@ -407,7 +405,6 @@ class SdpRelaxation(object):
         Arguments:
         filename -- the name of the file. It must have the suffix ".dat-s"
         """
-
         f = open(filename, 'w')
         f.write('"file ' + filename + ' generated by ncpol2sdpa"\n')
         f.write(str(self.n_vars) + ' = number of vars\n')
